#
# spec file for package efivar
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           efivar
Version:        0.23
Release:        3.28
Summary:        Tools to manage UEFI variables
License:        LGPL-2.1
Group:          Development/Libraries/Other
Url:            https://github.com/rhinstaller/efivar
Source0:        https://github.com/rhinstaller/efivar/releases/download/%{version}/%{name}-%{version}.tar.bz2
Patch1:         efivar-0.21-gcc6.diff
Patch2:         efivar-no-static.patch
Patch3:         efivar-nvme-rename.patch
Patch4:         efivar-nvme-no-kernel-header.patch
Patch5:         efivar-relicensing.patch
Patch6:         efivar-bsc988000-fix-mode-efi_set_variable.patch
Patch7:         efivar-bsc988000-remove-versioning-efi_set_variable.patch
BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  popt-devel
Requires:       libefivar0 = %{version}-%{release}

%description
efivar provides a simple command line interface to the UEFI variable facility.

%package -n libefivar0
Summary:        Library to manage UEFI variables
Group:          Development/Libraries/Other

%description -n libefivar0
Library to allow for the simple manipulation of UEFI variables.

%package devel
Summary:        Development headers for libefivar
Group:          Development/Libraries/Other
Requires:       libefivar0 = %{version}-%{release}

%description devel
development headers required to use libefivar.

%prep
%setup -q
%patch1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

%build
export CFLAGS="%{optflags} -Wno-nonnull"
make \
  libdir=%{_libdir} \
  bindir=%{_bindir}

%install
make DESTDIR=%{buildroot} libdir=%{_libdir} install
%fdupes -s %{buildroot}

%post -n libefivar0 -p /sbin/ldconfig

%postun -n libefivar0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/efivar
%{_mandir}/man1/*

%files devel
%defattr(-,root,root)
%{_mandir}/man3/*
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n libefivar0
%defattr(-,root,root)
%{_libdir}/*.so.*

%changelog
* Mon Jul 11 2016 glin@suse.com
- Add efivar-bsc988000-fix-mode-efi_set_variable.patch and
  efivar-bsc988000-remove-versioning-efi_set_variable.patch to set
  the default file mode rather than fetching a value randomly
  (bsc#988000)
* Wed Apr 13 2016 glin@suse.com
- Add efivar-relicensing.patch to update the license in some files
* Tue Apr 12 2016 glin@suse.com
- Add the missing COPYING
* Wed Mar  9 2016 glin@suse.com
- Update to 0.23 for fwupdate (FATE#319345)
- Add efivar-nvme-rename.patch and efivar-nvme-no-kernel-header.patch
  to work around the missing kernel header.
- Add efivar-no-static.patch to remove efivar-static since it
  causes build failure and we don't really need it.
- Remove efivar-fix-initializer.patch since it's already in 0.23.
- Remove _smp_mflags since the Makefile doesn't work well with
  the flag.
* Wed Feb 10 2016 rguenther@suse.com
- Add efivar-0.21-gcc6.diff to fix strict-aliasing issue.
- Build with -Wno-nonnull as efivar tests nonnull args for zero
  and that breaks with its use of -Werror.
* Tue Dec  1 2015 glin@suse.com
- Update the source link
* Fri Nov 27 2015 glin@suse.com
- Update to 0.21
- Add efivar-fix-initializer.patch to initialize ifreq properly
- Drop patches
  + efivar-fix-vars_del_variable.patch: upstreamed
  + efivar-revert-linker-order.patch: not necessary
* Wed Jun 24 2015 glin@suse.com
- Add efivar-fix-vars_del_variable.patch to fix the deletion of
  the variable with the old efivar kernel modules
* Tue Jun 16 2015 glin@suse.com
- Add efivar-revert-linker-order.patch to adjust the linker order
  which caused the compilation error in pesign
* Thu Jun 11 2015 mpluskal@suse.com
- Use default CFLAGS
* Wed Jun  3 2015 mpluskal@suse.com
- Update to 0.20
  * Make sure tester is build with the right link order for
    libraries.
  * Adjust linker order for pkg-config
  * Work around LocateDevicePath() not grokking PcieRoot() devices
    properly.
  * Rectify some missing changelog entries
- Changes for 0.19
  * Lots of debugging in this release, as well as some of the
    documentation that's planned. There's more of that to come.
- Changes for 0.18
  * This release is mostly about adding the efidp and libefiboot
    APIs available.Next release will feature documentation for
    them, verification that various different device path types
    work, etc. Right now efi device path generation is basically
    limited to:
    + full file paths on sata devices
    + full file paths on sas devices
    + HD() paths for SATA and SAS devices
    + ipv4 dhcp device paths that don't specify their own
    filenames
- Drop upstreamed patche
  * efivar-correct-license-header.patch
- Drop as Makefiles have been restructured, CFLAGS no longer
  defined in them
  * efivar-suse-build.patch
- Use fdupes to reduce amount of duplicate files
* Fri Nov  7 2014 glin@suse.com
- Add efivar-correct-license-header.patch to correct the license of
  util.h
- Amend the spec file with spec-cleaner
* Wed Oct 29 2014 glin@suse.com
- Update to 0.15
  + Make FSF addresses in COPYING be URLS
  + Fix variables' DataSize field on 32-bit machines.
  + Add some vendor specific guids to our guid list
  + Add efi_id_guid_to_name() and efi_name_to_id_guid(), which
    support {ID GUID} as a concept a la
    http://technet.microsoft.com/en-us/library/cc766223%%28v=ws.10%%29.aspx
  + Call "empty" "zero" now, as many other places do. (empty
    references still exist for ABI compatibility)
  + add "efivar -L" to the man page
  + efi_symbol_to_guid()
  + efi_name_to_guid() will fall back on efi_symbol_to_guid()
  + "efivar -L" to list all the guids we know about
  + better namespacing on libefivar.so
    (rename well_known_* -> efi_well_known_*)
- Refresh efivar-suse-build.patch
* Fri Sep 26 2014 glin@suse.com
- Update to 0.12
  + Make efi_guid_to_str() only optionally allocate.
  + Add ", mode" optionally to efi_set_variable()
  + Fix some return values that don't properly set errno.
  + Make "wrong size" test more verbose
  + Excise read_fd() since we've got read_file(), plus cleanups.
  + Remove variables we've failed to create.
  + Only open with O_CREAT if we're not using
    EFI_VARIABLE_APPEND_WRITE
  + Fix poptReadDefaultConfig() error checking
  + Get rid of ftruncate() call in efivarfs writes.
  + If the real file size of an efivarfs file is smaller than stat,
    get it right.
  + Fix uninitialized variables
  + Remove effectively dead code from text_to_guid()
  + Remove unnecessary explicit definitions or overrides of make
    variables
- refresh efivar-suse-build.patch
* Mon Nov  4 2013 glin@suse.com
- Initial import 0.7
